@@ -1,4 +1,11 @@
 context("Utilities")
+test_that("Missing packages are detected", {
+  expect_error(check_availability(packages = c("Missing"), func = "test"))
+})
+test_that("Found packages are detected silently", {
+  expect_silent(check_availability(packages = c("stats"), func = "test"))
+})
+
 test_that("Dollar Millions formats as expected", {
   expect_equal(dollar_millions(1.523 * 10^6), "$1.52M")
 })
